.. _sec-advanced:

Advanced: low-level lambeq
==========================

To understand ``lambeq`` in further depth, it is necessary to familiarise yourself with the low-level :py:mod:`lambeq.backend` module and its :ref:`available classes and methods <api_backend>`.

After these tutorials, you will have the necessary knowledge to contribute to ``lambeq``.

.. toctree::

    ../tutorials/monoidal.ipynb
    ../tutorials/discocat.ipynb
